[![Build Status](https://travis-ci.com/macornwell/opencv-image-and-video.svg?branch=master)](https://travis-ci.com/macornwell/opencv-image-and-video)
[![Coverage Status](https://coveralls.io/repos/github/macornwell/opencv-image-and-video/badge.svg?branch=master)](https://coveralls.io/github/macornwell/opencv-image-and-video?branch=master)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

# OpenCV Image and Video
If you have wanted to integrate OpenCV in an application for taking pictures, or recording a simple video this is the 
library and application to make it happen.

## How To Install
`pip install opencv-iav`

## Application
The application provided is the 'opencv_iav' script. This script allows a user to take a photo or record a video
of a given duration in seconds.

